## Design & Architecture of JAXA

Jaxa Client is a wrapper around:
- Jira REST API Client
- Jira XRay REST API Client
- Jira XRay GraphQL API Client

With all these API's available then we can perform all the updates to Jira that we need.
